==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/kasten/controllers/view/structures/script/scripthandler.hpp <==
/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2010, 2011 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef KASTEN_SCRIPTHANDLER_HPP
#define KASTEN_SCRIPTHANDLER_HPP

#include <QScopedPointer>

#include "scripthandlerinfo.hpp"

class DataInformation;
class ArrayDataInformation;
class TaggedUnionDataInformation;
class ScriptLogger;
class TopLevelDataInformation;
class QScriptEngineDebugger;
class QScriptValue;

class ScriptHandler
{
    Q_DISABLE_COPY(ScriptHandler)

public:
    ScriptHandler(QScriptEngine* engine, TopLevelDataInformation* topLevel);
    virtual ~ScriptHandler();

public:
    void validateData(DataInformation* data);
    /** The pointer may be changed while updating, CHECK AS SOON AS FUNCTION RETURNS! */
    void updateDataInformation(DataInformation* data);
    void updateLength(ArrayDataInformation* array);
    QString customToString(const DataInformation* data, const QScriptValue& func);

    QScriptEngine* engine() const;
    ScriptHandlerInfo* handlerInfo();

    QScriptValue callFunction(QScriptValue func, DataInformation* data, ScriptHandlerInfo::Mode mode);

private:
    QScopedPointer<QScriptEngine> mEngine;
    TopLevelDataInformation* mTopLevel;
    ScriptHandlerInfo mHandlerInfo;
};

#endif /* KASTEN_SCRIPTHANDLER_HPP */

==> okteta-0.26.23.tar.xz: okteta-0.26.23/kasten/controllers/view/structures/script/scripthandler.hpp <==
/*
    This file is part of the Okteta Kasten Framework, made within the KDE community.

    SPDX-FileCopyrightText: 2010, 2011 Alex Richardson <alex.richardson@gmx.de>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef KASTEN_SCRIPTHANDLER_HPP
#define KASTEN_SCRIPTHANDLER_HPP

#include <QScopedPointer>

#include "scripthandlerinfo.hpp"

class DataInformation;
class ArrayDataInformation;
class TaggedUnionDataInformation;
class ScriptLogger;
class TopLevelDataInformation;
class QScriptEngineDebugger;
class QScriptValue;

class ScriptHandler
{
public:
    ScriptHandler(QScriptEngine* engine, TopLevelDataInformation* topLevel);
    ScriptHandler(const ScriptHandler&) = delete;

    virtual ~ScriptHandler();

    ScriptHandler& operator=(const ScriptHandler&) = delete;

public:
    void validateData(DataInformation* data);
    /** The pointer may be changed while updating, CHECK AS SOON AS FUNCTION RETURNS! */
    void updateDataInformation(DataInformation* data);
    void updateLength(ArrayDataInformation* array);
    QString customToString(const DataInformation* data, const QScriptValue& func);

    QScriptEngine* engine() const;
    ScriptHandlerInfo* handlerInfo();

    QScriptValue callFunction(QScriptValue func, DataInformation* data, ScriptHandlerInfo::Mode mode);

private:
    QScopedPointer<QScriptEngine> mEngine;
    TopLevelDataInformation* mTopLevel;
    ScriptHandlerInfo mHandlerInfo;
};

#endif /* KASTEN_SCRIPTHANDLER_HPP */
